"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.help = exports.commandNames = exports.shorthands = exports.cliOptionsTypes = exports.rcOptionsTypes = void 0;
const cli_utils_1 = require("@pnpm/cli-utils");
const common_cli_options_help_1 = require("@pnpm/common-cli-options-help");
const config_1 = require("@pnpm/config");
const store_connection_manager_1 = require("@pnpm/store-connection-manager");
const core_1 = require("@pnpm/core");
const render_help_1 = __importDefault(require("render-help"));
const install_1 = require("./install");
Object.defineProperty(exports, "cliOptionsTypes", { enumerable: true, get: function () { return install_1.cliOptionsTypes; } });
exports.rcOptionsTypes = install_1.cliOptionsTypes;
exports.shorthands = {
    D: '--dev',
    P: '--production',
};
exports.commandNames = ['fetch'];
function help() {
    return (0, render_help_1.default)({
        description: 'Fetch packages from a lockfile into virtual store, package manifest is ignored. WARNING! This is an experimental command. Breaking changes may be introduced in non-major versions of the CLI',
        descriptionLists: [
            {
                title: 'Options',
                list: [
                    {
                        description: 'Only development packages will be fetched',
                        name: '--dev',
                        shortAlias: '-D',
                    },
                    {
                        description: 'Development packages will not be fetched',
                        name: '--prod',
                        shortAlias: '-P',
                    },
                    ...common_cli_options_help_1.UNIVERSAL_OPTIONS,
                ],
            },
        ],
        url: (0, cli_utils_1.docsUrl)('fetch'),
        usages: ['pnpm fetch [--dev | --prod]'],
    });
}
exports.help = help;
async function handler(opts) {
    const store = await (0, store_connection_manager_1.createOrConnectStoreController)(opts);
    const include = {
        dependencies: opts.production !== false,
        devDependencies: opts.dev !== false,
        // when including optional deps, production is also required when perform headless install
        optionalDependencies: opts.production !== false,
    };
    await (0, core_1.mutateModulesInSingleProject)({
        manifest: {},
        mutation: 'install',
        pruneDirectDependencies: true,
        rootDir: process.cwd(),
    }, {
        ...opts,
        ...(0, config_1.getOptionsFromRootManifest)(opts.rootProjectManifestDir, opts.rootProjectManifest ?? {}),
        ignorePackageManifest: true,
        include,
        modulesCacheMaxAge: 0,
        pruneStore: true,
        storeController: store.ctrl,
        storeDir: store.dir,
    });
}
exports.handler = handler;
//# sourceMappingURL=fetch.js.map