"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createLatestSpecs = exports.updateToLatestSpecsFromManifest = void 0;
const manifest_utils_1 = require("@pnpm/manifest-utils");
const version_selector_type_1 = __importDefault(require("version-selector-type"));
function updateToLatestSpecsFromManifest(manifest, include) {
    const allDeps = (0, manifest_utils_1.filterDependenciesByType)(manifest, include);
    const updateSpecs = [];
    for (const [depName, depVersion] of Object.entries(allDeps)) {
        if (depVersion.startsWith('npm:')) {
            updateSpecs.push(`${depName}@${removeVersionFromSpec(depVersion)}@latest`);
        }
        else {
            const selector = (0, version_selector_type_1.default)(depVersion);
            if (selector == null)
                continue;
            updateSpecs.push(`${depName}@latest`);
        }
    }
    return updateSpecs;
}
exports.updateToLatestSpecsFromManifest = updateToLatestSpecsFromManifest;
function createLatestSpecs(specs, manifest) {
    const allDeps = (0, manifest_utils_1.getAllDependenciesFromManifest)(manifest);
    return specs
        .filter((selector) => selector.includes('@', 1)
        ? allDeps[selector.slice(0, selector.indexOf('@', 1))]
        : allDeps[selector])
        .map((selector) => {
        if (selector.includes('@', 1)) {
            return selector;
        }
        if (allDeps[selector].startsWith('npm:')) {
            return `${selector}@${removeVersionFromSpec(allDeps[selector])}@latest`;
        }
        if ((0, version_selector_type_1.default)(allDeps[selector]) == null) {
            return selector;
        }
        return `${selector}@latest`;
    });
}
exports.createLatestSpecs = createLatestSpecs;
function removeVersionFromSpec(spec) {
    return spec.substring(0, spec.lastIndexOf('@'));
}
//# sourceMappingURL=updateToLatestSpecFromManifest.js.map